pub struct GraphEntry { /* private fields */ }Trait Implementations
Sourceimpl Clone for GraphEntry
impl Clone for GraphEntry
Sourcefn clone(&self) -> GraphEntry
fn clone(&self) -> GraphEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GraphEntry
impl Debug for GraphEntry
Sourceimpl<'de> Deserialize<'de> for GraphEntry
impl<'de> Deserialize<'de> for GraphEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for GraphEntry
Sourceimpl Hash for GraphEntry
impl Hash for GraphEntry
Sourceimpl JsonSchema for GraphEntry
impl JsonSchema for GraphEntry
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for GraphEntry
impl Ord for GraphEntry
Sourcefn cmp(&self, other: &GraphEntry) -> Ordering
fn cmp(&self, other: &GraphEntry) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GraphEntry
impl PartialEq for GraphEntry
Sourcefn eq(&self, other: &GraphEntry) -> bool
fn eq(&self, other: &GraphEntry) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for GraphEntry
impl PartialOrd for GraphEntry
Sourceimpl Serialize for GraphEntry
impl Serialize for GraphEntry
impl StructuralPartialEq for GraphEntry